import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { DeleteCommandRequest, DeleteCommandResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteCommandCommand}.
 */
export interface DeleteCommandCommandInput extends DeleteCommandRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteCommandCommand}.
 */
export interface DeleteCommandCommandOutput extends DeleteCommandResponse, __MetadataBearer {
}
declare const DeleteCommandCommand_base: {
    new (input: DeleteCommandCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteCommandCommandInput, DeleteCommandCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteCommandCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteCommandCommandInput, DeleteCommandCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Delete a command resource.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, DeleteCommandCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, DeleteCommandCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // DeleteCommandRequest
 *   commandId: "STRING_VALUE", // required
 * };
 * const command = new DeleteCommandCommand(input);
 * const response = await client.send(command);
 * // { // DeleteCommandResponse
 * //   statusCode: Number("int"),
 * // };
 *
 * ```
 *
 * @param DeleteCommandCommandInput - {@link DeleteCommandCommandInput}
 * @returns {@link DeleteCommandCommandOutput}
 * @see {@link DeleteCommandCommandInput} for command's `input` shape.
 * @see {@link DeleteCommandCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>The request conflicts with the current state of the resource.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Internal error from the service that indicates an unexpected error or that the service
 *             is unavailable.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate exceeds the limit.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class DeleteCommandCommand extends DeleteCommandCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteCommandRequest;
            output: DeleteCommandResponse;
        };
        sdk: {
            input: DeleteCommandCommandInput;
            output: DeleteCommandCommandOutput;
        };
    };
}
