import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { ListCommandsRequest, ListCommandsResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListCommandsCommand}.
 */
export interface ListCommandsCommandInput extends ListCommandsRequest {
}
/**
 * @public
 *
 * The output of {@link ListCommandsCommand}.
 */
export interface ListCommandsCommandOutput extends ListCommandsResponse, __MetadataBearer {
}
declare const ListCommandsCommand_base: {
    new (input: ListCommandsCommandInput): import("@smithy/smithy-client").CommandImpl<ListCommandsCommandInput, ListCommandsCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [ListCommandsCommandInput]): import("@smithy/smithy-client").CommandImpl<ListCommandsCommandInput, ListCommandsCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>List all commands in your account.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, ListCommandsCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, ListCommandsCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // ListCommandsRequest
 *   maxResults: Number("int"),
 *   nextToken: "STRING_VALUE",
 *   namespace: "AWS-IoT" || "AWS-IoT-FleetWise",
 *   commandParameterName: "STRING_VALUE",
 *   sortOrder: "ASCENDING" || "DESCENDING",
 * };
 * const command = new ListCommandsCommand(input);
 * const response = await client.send(command);
 * // { // ListCommandsResponse
 * //   commands: [ // CommandSummaryList
 * //     { // CommandSummary
 * //       commandArn: "STRING_VALUE",
 * //       commandId: "STRING_VALUE",
 * //       displayName: "STRING_VALUE",
 * //       deprecated: true || false,
 * //       createdAt: new Date("TIMESTAMP"),
 * //       lastUpdatedAt: new Date("TIMESTAMP"),
 * //       pendingDeletion: true || false,
 * //     },
 * //   ],
 * //   nextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListCommandsCommandInput - {@link ListCommandsCommandInput}
 * @returns {@link ListCommandsCommandOutput}
 * @see {@link ListCommandsCommandInput} for command's `input` shape.
 * @see {@link ListCommandsCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Internal error from the service that indicates an unexpected error or that the service
 *             is unavailable.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate exceeds the limit.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class ListCommandsCommand extends ListCommandsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListCommandsRequest;
            output: ListCommandsResponse;
        };
        sdk: {
            input: ListCommandsCommandInput;
            output: ListCommandsCommandOutput;
        };
    };
}
